@@ -221,8 +221,8 @@ double pen_bias(double h, double mu_h, double sigma2_h) {
   }
 
   double pen;
-  if (arma::is_finite(sigma2_h)) {
-    pen = -std::log(h) - std::pow(std::log(h) - mu_h, 2) / (2.0 * sigma2_h);
+  if (std::isfinite(sigma2_h)) {
+    pen = -1.0 * std::pow(std::log(h) - mu_h, 2.0) / (2.0 * sigma2_h);
   } else {
     pen = 0.0;
   }
@@ -256,7 +256,7 @@ double pen_seq_error(double eps, double mu_eps, double sigma2_eps) {
   }
 
   double pen;
-  if (arma::is_finite(sigma2_eps)) {
+  if (std::isfinite(sigma2_eps)) {
     pen = -log(eps * (1.0 - eps)) - std::pow(logit(eps) - mu_eps, 2) / (2.0 * sigma2_eps);
   } else {
     pen = 0.0;
