@@ -1,8 +1,4 @@
-context("flexdog")
-
 test_that("flexdog works", {
-  skip_on_os(os = "mac", arch = "aarch64")
-
   refvec    <- 1:20
   sizevec   <- 40:21
 
@@ -60,10 +56,11 @@ test_that("flexdog works", {
   pivec <- pivec / sum(pivec)
   expect_equal(pivec, fout$gene_dist)
 
-  expect_warning(fout <- flexdog(refvec = refvec, sizevec = sizevec,
-                                 ploidy = ploidy, model = "uniform", verbose = FALSE))
-  expect_equal(fout$gene_dist, rep(1 / (ploidy + 1), ploidy + 1))
-  pl <- plot(fout)
+  # expect_warning({
+  #   fout <- flexdog(refvec = refvec, sizevec = sizevec, ploidy = ploidy, model = "uniform", verbose = FALSE)
+  #   })
+  # expect_equal(fout$gene_dist, rep(1 / (ploidy + 1), ploidy + 1))
+  # pl <- plot(fout)
   # suppressWarnings(
   # fout <- flexdog(refvec = refvec, sizevec = sizevec,
   #                 p2ref = 10, p2size = 20,
@@ -81,8 +78,6 @@ test_that("flexdog works", {
 )
 
 test_that("don't update bias, seq, od when supposed not to", {
-  skip_on_os(os = "mac", arch = "aarch64")
-
   refvec  <- 1:20
   sizevec <- 40:21
   ploidy  <- 4
@@ -106,8 +101,6 @@ test_that("don't update bias, seq, od when supposed not to", {
 })
 
 test_that("fs1_alpha works", {
-  skip_on_os(os = "mac", arch = "aarch64")
-
   refvec  <- 1:20
   sizevec <- 40:21
   ploidy  <- 4
@@ -131,8 +124,6 @@ test_that("fs1_alpha works", {
 })
 
 test_that("actually using parent data", {
-  skip_on_os(os = "mac", arch = "aarch64")
-
   refvec  <- 1:20
   sizevec <- 40:21
   ploidy  <- 6
@@ -183,8 +174,6 @@ test_that("actually using parent data", {
 })
 
 test_that("genotype likelihoods and posteriors are consistent", {
-  skip_on_os(os = "mac", arch = "aarch64")
-
   refvec <- c(1, 2, 1, 3, 2)
   sizevec <- c(4, 2, 2, 3, 4)
   ploidy <- 4
