@@ -1,8 +1,4 @@
-context("rflexdog")
-
 test_that("rgeno works", {
-  skip_on_os(os = "mac", arch = "aarch64")
-
   pivec <- runif(7)
   pivec <- pivec / sum(pivec)
   trash <- rgeno(n = 10, ploidy = 6, model = "hw", allele_freq = 0.5)
@@ -16,8 +12,6 @@ test_that("rgeno works", {
 })
 
 test_that("rflexdog works", {
-  skip_on_os(os = "mac", arch = "aarch64")
-
   set.seed(1)
   sizevec <- rep(1000000, length = 7)
   geno    <- 0:6
@@ -26,5 +20,5 @@ test_that("rflexdog works", {
   bias    <- 1
   od      <- 0
   tvec <- rflexdog(sizevec = sizevec, geno = geno, ploidy = ploidy, seq = seq, bias = bias, od = od) / 1000000
-  expect_equal(tvec, (0:6) / 6, tol = 10^-2)
+  expect_equal(tvec, (0:6) / 6, tolerance = 10^-2)
 })
