@@ -1,8 +1,4 @@
-context("util funs")
-
 test_that("xi_fun and eta_fun works", {
-  skip_on_os(os = "mac", arch = "aarch64")
-
   p <- seq(0, 1, length = 20)
   eps <- 0.1
   h <- 0.2
@@ -26,8 +22,6 @@ test_that("xi_fun and eta_fun works", {
 )
 
 test_that("log_sum_exp works", {
-  skip_on_os(os = "mac", arch = "aarch64")
-
   set.seed(1)
   x <- abs(rnorm(10))
 
@@ -42,8 +36,6 @@ test_that("log_sum_exp works", {
 )
 
 test_that("logit works", {
-  skip_on_os(os = "mac", arch = "aarch64")
-
   expect_equal(logit(0.1), log(0.1 / 0.9))
   expect_equal(expit(logit(0.1)), 0.1)
   expect_equal(logit(expit(-8)), -8)
@@ -51,16 +43,12 @@ test_that("logit works", {
 )
 
 test_that("log_sum_exp and log_sum_exp_2 are equal", {
-  skip_on_os(os = "mac", arch = "aarch64")
-
   expect_equal(log_sum_exp(c(0.1, 0.2)),
                log_sum_exp_2(0.1, 0.2))
 }
 )
 
 test_that("log_sum_exp and log_sum_exp_2 works with -Inf", {
-  skip_on_os(os = "mac", arch = "aarch64")
-
   expect_true(!is.nan(log_sum_exp(c(-Inf, -Inf))))
   expect_true(!is.nan(log_sum_exp_2(-Inf, -Inf)))
   expect_true(is.infinite(log_sum_exp(c(-Inf, -Inf))))
